==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetShareSubscriptionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property resourceGroupName The resource group name.
 * @property shareSubscriptionName The name of the shareSubscription.
 */
public data class GetShareSubscriptionPlainArgs(
    public val accountName: String,
    public val resourceGroupName: String,
    public val shareSubscriptionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareSubscriptionName(shareSubscriptionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetShareSubscriptionPlainArgs].
 */
@PulumiTagMarker
public class GetShareSubscriptionPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var resourceGroupName: String? = null

    private var shareSubscriptionName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("hvatedrunrlvrnjl")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("wgvasraddmvapoxx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the shareSubscription.
     */
    @JvmName("eymdspjkwioqrioa")
    public suspend fun shareSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareSubscriptionName = mapped
    }

    internal fun build(): GetShareSubscriptionPlainArgs = GetShareSubscriptionPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareSubscriptionName = shareSubscriptionName ?: throw
            PulumiNullFieldException("shareSubscriptionName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetShareSubscriptionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property resourceGroupName The resource group name.
 * @property shareSubscriptionName The name of the shareSubscription.
 */
public data class GetShareSubscriptionPlainArgs(
    public val accountName: String,
    public val resourceGroupName: String,
    public val shareSubscriptionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetShareSubscriptionPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareSubscriptionName(shareSubscriptionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetShareSubscriptionPlainArgs].
 */
@PulumiTagMarker
public class GetShareSubscriptionPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var resourceGroupName: String? = null

    private var shareSubscriptionName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("ofsnswlshsefqnui")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("bqubhqlcwsxbtboj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the shareSubscription.
     */
    @JvmName("dnxxxfrywnktxcqs")
    public suspend fun shareSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareSubscriptionName = mapped
    }

    internal fun build(): GetShareSubscriptionPlainArgs = GetShareSubscriptionPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareSubscriptionName = shareSubscriptionName ?: throw
            PulumiNullFieldException("shareSubscriptionName"),
    )
}
